Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Fault Injection Simulator.

Actions, resources, and condition keys for AWS Fault Injection Simulator - Service Authorization Reference

# Actions, resources, and condition keys for AWS Fault Injection Simulator

AWS Fault Injection Simulator (service prefix: `fis` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Fault Injection Simulator
- Resource types defined by AWS Fault Injection Simulator
- Condition keys for AWS Fault Injection Simulator

## Actions defined by AWS Fault Injection Simulator

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateExperimentTemplate | Grants permission to create an AWS FIS experiment template | Write | action* |  |
experiment-template* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteExperimentTemplate | Grants permission to delete the AWS FIS experiment template | Write | experiment-template* |  |
GetAction | Grants permission to retrieve an AWS FIS action | Read | action* |  |
| aws:ResourceTag/${TagKey} |
GetExperiment | Grants permission to retrieve an AWS FIS experiment | Read | experiment* |  |
| aws:ResourceTag/${TagKey} |
GetExperimentTemplate | Grants permission to retrieve an AWS FIS Experiment Template | Read | experiment-template* |  |
| aws:ResourceTag/${TagKey} |
InjectApiInternalError | Grants permission to inject an API internal error on the provided AWS service from an FIS Experiment | Write | experiment* |  |
| fis:Service fis:Operations fis:Percentage fis:Targets |
InjectApiThrottleError | Grants permission to inject an API throttle error on the provided AWS service from an FIS Experiment | Write | experiment* |  |
| fis:Service fis:Operations fis:Percentage fis:Targets |
InjectApiUnavailableError | Grants permission to inject an API unavailable error on the provided AWS service from an FIS Experiment | Write | experiment* |  |
| fis:Service fis:Operations fis:Percentage fis:Targets |
ListActions | Grants permission to list all available AWS FIS actions | List |  |  |
ListExperimentTemplates | Grants permission to list all available AWS FIS experiment templates | List |  |  |
ListExperiments | Grants permission to list all available AWS FIS experiments | List |  |  |
ListTagsForResource | Grants permission to list the tags for an AWS FIS resource. | Read | action |  |
experiment |  |
experiment-template |  |
StartExperiment | Grants permission to run an AWS FIS experiment | Write | experiment* |  | iam:CreateServiceLinkedRole
experiment-template* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
StopExperiment | Grants permission to stop an AWS FIS experiment | Write | experiment* |  |
TagResource | Grants permission to tag AWS FIS resources | Tagging | action |  |
experiment |  |
experiment-template |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to untag AWS FIS resources | Tagging | action |  |
experiment |  |
experiment-template |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UpdateExperimentTemplate | Grants permission to update the specified AWS FIS experiment template | Write | experiment-template* |  |
action |  |
| aws:RequestTag/${TagKey} aws:TagKeys |

## Resource types defined by AWS Fault Injection Simulator

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
action | `arn:$ { Partition}:fis:$ { Region}:$ { Account}:action/$ { Id}` | aws:ResourceTag/${TagKey}
experiment | `arn:$ { Partition}:fis:$ { Region}:$ { Account}:experiment/$ { Id}` | aws:ResourceTag/${TagKey}
experiment-template | `arn:$ { Partition}:fis:$ { Region}:$ { Account}:experiment-template/$ { Id}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Fault Injection Simulator

AWS Fault Injection Simulator defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a tag key and value pair that is allowed in the request | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair of a resource | String
aws:TagKeys | Filters access by a list of tag keys that are allowed in the request | String
fis:Operations | Filters access by the list of operations on the AWS service that is being affected by the AWS FIS action | ArrayOfString
fis:Percentage | Filters access by the percentage of calls being affected by the AWS FIS action | Numeric
fis:Service | Filters access by the AWS service that is being affected by the AWS FIS action | String
fis:Targets | Filters access by the list of resource ARNs being targeted by the AWS FIS action | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.